/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.service;

import se.vgregion.portal.vap.domain.jpa.Bookmark;

import java.util.Collection;

/**
 * Service for managing {@link Bookmark}s.
 *
 * @author Patrik Bergström
 */
public interface BookmarkService {

    /**
     * Find all {@link Bookmark}s for a given user.
     *
     * @param userId the user's userId
     * @return all the user's {@link Bookmark}s
     */
    Collection<Bookmark> findBookmarksByUserId(Long userId);

    /**
     * Add (persist) a {@link Bookmark}. A {@link Bookmark} is made up of a userId, documentId and folderName. If the
     * folder does not exist it should be created.
     *
     * @param userId the userId
     * @param documentId the documentId
     * @param folderName the folderName
     */
    void addBookmark(Long userId, String documentId, String folderName);

    /**
     * Find all {@link Bookmark}s for all users and all folders.
     *
     * @return all {@link Bookmark}s
     */
    Collection<Bookmark> findAll();

    /**
     * Remove a {@link Bookmark}.
     *
     * @param bookmark the {@link Bookmark}
     */
    void remove(Bookmark bookmark);

    /**
     * Remove all {@link Bookmark}s.
     */
    void removeAll();
}
