/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.service;

import se.vgregion.portal.vap.domain.jpa.Folder;

import java.util.Collection;

/**
 * Service for managing {@link Folder}s.
 *
 * @author Patrik Bergström
 */
public interface FolderService {

    /**
     * Persist a {@link Folder}.
     *
     * @param folder the folder
     */
    void persist(Folder folder);

    /**
     * Merge a {@link Folder}.
     *
     * @param folder the {@link Folder}
     * @return the merged instance
     */
    Folder merge(Folder folder);

    /**
     * Find all {@link Folder}s.
     *
     * @return a {@link Collection} of all {@link Folder}s
     */
    Collection<Folder> findAll();

    /**
     * Remove a {@link Folder}.
     *
     * @param id the id of the {@link Folder}
     */
    void remove(Long id);

    /**
     * Find all {@link Folder}s by a userId.
     *
     * @param userId the userId
     * @return a {@link Collection} of {@link Folder}s
     */
    Collection<Folder> findByUserId(Long userId);
}
