/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import se.vgregion.portal.vap.domain.jpa.Folder;
import se.vgregion.portal.vap.service.repository.FolderRepository;

import java.util.Collection;

/**
 * Implementation of {@link FolderService}.
 *
 * @author Patrik Bergström
 */
public class FolderServiceImpl implements FolderService {

    private static final Logger LOGGER = LoggerFactory.getLogger(FolderServiceImpl.class);

    private FolderRepository folderRepository;

    /**
     * Constructor.
     *
     * @param folderRepository the {@link FolderRepository}
     */
    @Autowired
    public FolderServiceImpl(FolderRepository folderRepository) {
        this.folderRepository = folderRepository;
    }

    @Override
    public void persist(Folder folder) {
        folderRepository.persist(folder);
    }

    @Override
    public Folder merge(Folder folder) {
        return folderRepository.merge(folder);
    }

    @Override
    public Collection<Folder> findAll() {
        return folderRepository.findAll();
    }

    @Override
    public void remove(Long id) {
        folderRepository.remove(id);
    }

    @Override
    public Collection<Folder> findByUserId(Long userId) {
        return folderRepository.findByUserId(userId);
    }

}
